<?php

namespace App\Helpers;

use App\Models\Affiliate;
use App\Models\CommissionEmployee;
use App\Models\DepositEmployee;
use App\Models\Employee;
use Exception;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use function PHPUnit\Framework\throwException;

class ImportHelper
{
    public static function syncEmployeeAndCommissionByCommission($parent, $data): bool
    {
        try {
            $collection = collect($data);
            $excelData = $collection->slice(3, count($data) - 4)->values();
            foreach ($excelData as $key => $impData) {
                $existEmployee = Employee::where('login_id', $impData[0])->first();
                if ($existEmployee) {
                    if($existEmployee->emp_name == 'Unknown') {
                        $existEmployee->emp_name = $impData[1];
                    }
                    $existEmployee->commission_balance += $impData[10] < 0 ? 0 : $impData[10];
                    $existEmployee->save();
                    if ($existEmployee->id) {
                        self::entryCommissionEmployeeByCommission($existEmployee->id, $parent->id, $impData);
                    }
                }
            }
            return true;
        } catch (\Exception $e) {
            info($e->getMessage());
            return false;
        }
    }

    public static function syncEmployeeAndCommissionByDeposit($parent, $data): bool
    {
        try {
            $collection = collect($data);
            $excelData = $collection->slice(1, count($data) - 2)->values();

            foreach ($excelData as $key => $impData) {
                $existEmployee = Employee::where('login_id', $impData[9])->first();
                if ($existEmployee) {
                    $existEmployee->deposit_balance += $impData[5] < 0 ? 0 : $impData[5];
                    $existEmployee->save();
                    if ($existEmployee->id) {
                        self::entryCommissionEmployeeByDeposit($existEmployee->id, $parent->id, $impData);
                    }
                }
            }
            return true;
        } catch (\Exception $e) {
            info($e->getMessage());
            return false;
        }
    }

    public static function entryCommissionEmployeeByCommission($empId, $parentId, $data)
    {
        $store = new CommissionEmployee();
        $store->import_id = $parentId;
        $store->employee_id = $empId;
        $store->ag_login_id = $data[0];
        $store->emp_name = $data[1];
        $store->valid_turn = $data[2];
        $store->active_member = $data[3];
        $store->member_WL = $data[4];
        $store->member_jackpot_WL = $data[5];
        $store->member_comm = $data[6];
        $store->member_totla_PL = $data[7];
        $store->downlines_PT_WL = $data[8];
        $store->downlines_comm = $data[9];
        $store->downlines_total_PL = $data[10];
        $store->self_PT_WL = $data[11];
        $store->self_comm = $data[12];
        $store->self_total_PL = $data[13];
        $store->company = $data[14];
        $store->total_commission = $data[10] < 0 ? 0 : $data[10];
        $store->due_commission = $data[10] < 0 ? 0 : $data[10];
        $store->paid_commission = 0;
        $store->save();
    }

    public static function entryCommissionEmployeeByDeposit($empId, $parentId, $data)
    {
        $employeeInfo = Employee::where('login_id', $empId)->first();
        $store = new DepositEmployee();
        $store->import_id = $parentId;
        $store->employee_id = $empId;
        $store->ag_login_id = $data[9];
        $store->emp_name = $employeeInfo?->emp_name ?? 'Unknown';
        $store->plus_minus = $data[5];
        $store->first_deposit = $data[11];
        $store->save();
    }

    public static function validateCommissionImportEmployee($data,$periodId): bool|string
    {
        try {
            $collection = collect($data);
            $excelData = $collection->slice(3, count($data) - 5)->values();
            $empIDs = $excelData->pluck(0)->toArray(); // Extract all employee IDs

            // Find duplicate employee IDs (IDs that appear more than once)
            $duplicateIDs = array_values(array_keys(array_filter(array_count_values($empIDs), fn($count) => $count > 1)));

            // Get unique employee IDs for database lookup
            $uniqueEmpIDs = array_unique($empIDs);

            // Get existing employee IDs from the database
            $existingIDs = Employee::whereIn('login_id', $uniqueEmpIDs)->pluck('login_id')->toArray();

            //user already exists in same period
            $periodEmpExists = CommissionEmployee::whereIn('ag_login_id', $uniqueEmpIDs)->whereHas('importInfo', function ($query) use ($periodId) {
                return $query->where('period_id', $periodId);
            })->get('ag_login_id','import_id');

            // Find missing employee IDs
            $missingIDs = array_values(array_diff($uniqueEmpIDs, $existingIDs));

            // If duplicates or missing IDs exist, return them
            if (!empty($duplicateIDs)) {
                $implodedData = implode(',', $duplicateIDs);
                return "Duplicate User ID {$implodedData} found";
            }
            if(!empty($missingIDs)) {
                $implodedData = implode(',', $missingIDs);
                return "User ID {$implodedData} not exists in the system. Please add user first";
            }
            if(count($periodEmpExists) > 0) {
                $implodedData = implode(',', $periodEmpExists->pluck('ag_login_id')->toArray());
                return "User ID {$implodedData} already exists in this period. Please check the import data";
            }

            return false;
        } catch (\Exception $e) {
            return 'Something bad happened'; // dummy exception
        }
    }

    public static function validateDepositImportEmployee($data): bool|string
    {
        try {
            $collection = collect($data);
            $excelData = $collection->slice(1, count($data) - 2)->values();
            $empIDs = $excelData->pluck(9)->toArray();
            // Find duplicate employee IDs (IDs that appear more than once)
            $duplicateIDs = array_values(array_keys(array_filter(array_count_values($empIDs), fn($count) => $count > 1)));
            // Get unique employee IDs for database lookup
            $uniqueEmpIDs = array_unique($empIDs);
            // Get existing employee IDs from the database
            $existingIDs = Employee::whereIn('login_id', $uniqueEmpIDs)->pluck('login_id')->toArray();

            // Find missing employee IDs
            $missingIDs = array_values(array_diff($uniqueEmpIDs, $existingIDs));

            // If duplicates or missing IDs exist, return them
        //    if (!empty($duplicateIDs)) {
        //        $implodedData = implode(', ', $duplicateIDs);
        //        return "Duplicate User ID {$implodedData} found";
        //    }
            if(!empty($missingIDs)) {
                $implodedData = implode(', ', $missingIDs);
                return "User ID {$implodedData} not exists in the system. Please add user first";
            }

            return false;
        } catch (\Exception $e) {
            info($e->getMessage());
            return "Something went wrong";
        }
    }

    public static function validateImportEmployee($data): bool|array
    {
        try {
            $collection = collect($data);
            $excelData = $collection->slice(0, count($data) - 1)->values();
            $empIDs = $excelData->pluck(2)->toArray();
            $existEmployee = Employee::whereIn('login_id', $empIDs)->get();
            $totalExistingEmployees = $existEmployee->count();
            if ($totalExistingEmployees > 0) {
                return $existEmployee->pluck('login_id')->toArray();
            }
            return 0;
        } catch (\Exception $e) {
            return ['unhandle']; //dummy exception
        }
    }

    public static function importEmployee($data): bool|array
    {
        try {
            DB::beginTransaction();
            $collection = collect($data);
            $excelData = $collection->slice(1, count($data) - 1)->values();

            $employees = [];
            foreach ($excelData as $value) {
                $affiliate = Affiliate::where(['name' => Str::lower($value[0])])->first();
                if (!$affiliate) {
                    $affiliate = new Affiliate();
                    $affiliate->name = Str::lower($value[0]);
                    $affiliate->save();
                }
                $employees[] = [
                    // 'login_id' => $value[2],
                    // 'affiliate_id' => $affiliate->id,
                    // 'emp_name' => $value[7] ?? 'Unknown',
                    // 'import_data' => json_encode($value),
                    // 'password' => Hash::make(12345678),
                    // 'created_at' => now(),
                    // 'created_by' => Auth::id(),
                    // 'updated_at' => now(),



                    'affiliate_id'              => $affiliate->id,
                    'upline_id_number'          => $value[1] ?? 'Unknown',
                    'login_id'                  => $value[2],
                    'tg'                        => $value[3] ?? 'Unknown',
                    'ag_user_name'              => $value[4] ?? 'Unknown',
                    'reg_date'                  => $value[5] ?? 'Unknown',
                    'reg_time'                  => $value[6] ?? 'Unknown',
                    'emp_name'                  => $value[7] ?? 'Unknown',
                    'email'                     => $value[8] ?? 'Unknown',
                    'phone_number'              => $value[9] ?? 'Unknown',
                    'internal'                  => $value[10] ?? 'Unknown',
                    'status'                    => $value[11] ?? 'Unknown',
                    'PT_commission_structure'   => $value[12] ?? 'Unknown',
                    'import_data'               => json_encode($value),
                    'password'                  => Hash::make(12345678),
                    'created_at'                => now(),
                    'created_by'                => Auth::id(),
                    'updated_at'                => now(),
                ];
            }
            Employee::insert($employees);
            DB::commit();
            return true;
        } catch (\Exception $e) {
            DB::rollback();
            info($e->getMessage());
            return false;
        }
    }
}