<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;

class AuthController extends Controller
{
    public function login(Request $request)
    {
        try {
            if (Auth::check()) {
                return redirect()->route('admin.dashboard');
            }
            return view("auth.login");
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function submitLogin(Request $request)
    {
        $credentials = $request->validate([
            'email' => ['required', 'email'],
            'password' => ['required'],
        ]);

        if (Auth::attempt($credentials)) {
            return redirect()->route("admin.dashboard");
        }

        return redirect()->back()->with("error", "Provided credentials doesn't match.");
    }

    public function logout(Request $request)
    {
        try {
            Auth::logout();
            return redirect()->route('auth.login');
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }
}
