<?php

namespace App\Http\Controllers\Commission;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Adjustment;
use App\Models\Period;
use App\Models\Employee;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;

class AdjustmentController extends Controller
{
    public function index(Request $request)
    {
        try {
            $search = !empty($request->search) ? $request->search : '';
            $listData = Adjustment::with(['period:id,name', 'createdBy:id,name', 'updatedBy:id,name'])
                ->when($search != '', function ($query) use ($search) {
                    return $query->where('login_id', 'like', "%{$search}%");
                })
                ->orderBy('id', 'desc')
                ->paginate(10);

            return view("admin.adjustment.list", compact('listData'));
        } catch (\Exception $th) {
            Log::info($th);
        }
    }


    public function create()
    {
        $periods = Period::all();
        return view('admin.adjustment.create', compact('periods'));
    }

    public function store(Request $request)
    {
        $validate = $this->validate($request, [
            'login_id' => 'required|exists:employees,login_id',
            'period_id' => 'required|exists:periods,id',
            'adjustment_type' => 'required',
            'adjustment_for' => 'required',
            'adjustment_amount' => ['required', 'numeric', 'regex:/^\d+(\.\d+)?$/'],
            'remarks' => 'nullable|string|max:100',

        ]);

        $existingAdjustment = Adjustment::where('login_id', $request->login_id)
            ->where('period_id', $request->period_id)
            ->where('adjustment_type', $request->adjustment_type)
            ->where('adjustment_for', $request->adjustment_for)
            ->first();

        if ($existingAdjustment) {
            // If the combination already exists, return an error message
            return back()->with(['error' => $request->login_id . ' - This Agents,Period and Adjustment type combination already exists.']);
        }

        $adjustment = new Adjustment();
        $adjustment->login_id = $request->login_id;
        $adjustment->period_id = $request->period_id;
        $adjustment->adjustment_type = $request->adjustment_type;
        $adjustment->adjustment_for = $request->adjustment_for;
        $adjustment->adjustment_amount = $request->adjustment_amount;
        $adjustment->remarks = $request->remarks;
        $adjustment->save();

        return redirect()->route('commission.adjustment.list')->with('success', 'Adjustment data inserted successfully.');
    }

    public function edit($id)
    {
        $periods = Period::all();
        $adjustment = Adjustment::where('id', $id)->first();
        return view('admin.adjustment.edit', compact('periods', 'adjustment'));
    }

    public function update(Request $request)
    {
        $validate = $this->validate($request, [
            'row_id' => 'required',
            'login_id' => 'required|exists:employees,login_id',
            'period_id' => 'required|exists:periods,id',
            'adjustment_type' => 'required',
            'adjustment_for' => 'required',
            'adjustment_amount' => ['required', 'numeric', 'regex:/^\d+(\.\d+)?$/'],
            'remarks' => 'nullable|string|max:100',

        ]);

        $existingAdjustment = Adjustment::where('login_id', $request->login_id)
            ->where('period_id', $request->period_id)
            ->where('adjustment_type', $request->adjustment_type)
            ->where('adjustment_for', $request->adjustment_for)
            ->where('id', '!=', $request->row_id)
            ->first();

        if ($existingAdjustment) {
            // If the combination already exists, return an error message
            return back()->with(['error' => $request->login_id . ' - This Agents,Period and Adjustment type combination already exists.']);
        }

        $adjustment = Adjustment::where('id', '=', $request->row_id)->first();
        $adjustment->login_id = $request->login_id;
        $adjustment->period_id = $request->period_id;
        $adjustment->adjustment_type = $request->adjustment_type;
        $adjustment->adjustment_for = $request->adjustment_for;
        $adjustment->adjustment_amount = $request->adjustment_amount;
        $adjustment->remarks = $request->remarks;
        $adjustment->save();

        return redirect()->route('commission.adjustment.list')->with('success', 'Adjustment data updated successfully.');
    }
}
