<?php

namespace App\Http\Controllers\Commission\Agent;

use App\Helpers\ImportHelper;
use App\Http\Controllers\Controller;
use App\Imports\CommissionFileImport;
use App\Models\Employee;
use App\Models\Affiliate;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;
use Maatwebsite\Excel\Facades\Excel;

class AgentController extends Controller
{
    public function index(Request $request)
    {
        try {
            $search = !empty($request->search) ? $request->search : '';
            $users = Employee::with(['createdBy:id,name', 'updatedBy:id,name'])
                ->when($search != '', function ($query) use ($search) {
                    return $query->where('login_id', 'like', "%{$search}%")
                        ->orWhere('email', 'like', "%{$search}%")
                        ->orWhere('phone_number', 'like', "%{$search}%")
                        ->orWhere('wallet_no', 'like', "%{$search}%");
                })
                ->orderBy('id', 'desc')
                ->paginate(10);

            return view("admin.agent.list", compact("users"));
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function create(Request $request)
    {
        try {
            $affiliates = Affiliate::all();
            return view("admin.agent.create",compact('affiliates'));
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function store(Request $request)
    {
        $validator = $this->validate($request, [
            "login_id" => "required|unique:employees,login_id",
            "affiliate_id" => "required",
            "name" => "required",
            "email" => "required|unique:employees,email",
            "phone" => "nullable|unique:employees,phone_number",
            "social_channel" => "required",
            "social_channel_details" => "required",
            "payment_method" => "required",
            "bank_name" => "required_if:payment_method,1",
            "account_holder_name" => "required_if:payment_method,1",
            "account_no" => "required_if:payment_method,1|unique:employees,bank_account_no",
            "branch_name" => "required_if:payment_method,1",
            "ewallet_type" => "required_if:payment_method,2",
            "ewallet_holder_name" => "required_if:payment_method,2",
            "ewallet_number" => "required_if:payment_method,2|unique:employees,wallet_no",
            "usdt_network" => "required_if:payment_method,3",
            "usdt_address" => "required_if:payment_method,3",
            // "password" => "required|confirmed|min:6",
        ]);

        try {
            $store = new Employee();
            $store->login_id = $request->login_id;
            $store->affiliate_id = $request->affiliate_id;
            $store->emp_name = $request->name;
            $store->email = $request->email;
            $store->phone_number = $request->phone;
            $store->social_channel = $request->social_channel;
            $store->social_channel_details = $request->social_channel_details;
            $store->payment_method = $request->payment_method;
            if($request->payment_method == 1) {
                $store->bank_name = $request->bank_name;
                $store->bank_holder_name = $request->account_holder_name;
                $store->bank_account_no = $request->account_no;
                $store->branch_name = $request->branch_name;

                $store->wallet_type = '';
                $store->wallet_no = '';
                $store->wallet_holder_name = '';

                $store->usdt_network = '';
                $store->usdt_address = '';
            }elseif($request->payment_method ==2) {
                $store->wallet_type = $request->ewallet_type;
                $store->wallet_no = $request->ewallet_number;
                $store->wallet_holder_name = $request->ewallet_holder_name;

                $store->bank_name = '';
                $store->bank_holder_name = '';
                $store->bank_account_no = '';
                $store->branch_name = '';

                $store->usdt_network = '';
                $store->usdt_address = '';
            }else {
                $store->usdt_network = $request->usdt_network;
                $store->usdt_address = $request->usdt_address;

                $store->bank_name = '';
                $store->bank_holder_name = '';
                $store->bank_account_no = '';
                $store->branch_name = '';

                $store->wallet_type = '';
                $store->wallet_no = '';
                $store->wallet_holder_name = '';
            }
            $store->password = Hash::make('12345678');
            $store->save();
            if ($store->id) {
                return redirect()->route('commission.agent.list')->with("success", "Agent added successfully");
            }
            return redirect()->back()->with("error", "Failed to add agent");
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function edit($id)
    {
        try {
            $affiliates = Affiliate::all();
            $agent = Employee::with(['createdBy:id,name', 'updatedBy:id,name'])
                ->where('id', $id)
                ->first();
            return view("admin.agent.edit", compact("agent","affiliates"));
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function update(Request $request)
    {
        $validator = $this->validate($request, [
            'row_id' => "required",
            "login_id" => "required|unique:employees,login_id,".$request->row_id,
            "affiliate_id" => "required",
            "name" => "required",
            "email" => "required|unique:employees,email,".$request->row_id,
            "phone" => "nullable|unique:employees,phone_number,".$request->row_id,
            "social_channel" => "required",
            "social_channel_details" => "required",
            "payment_method" => "required",
            "bank_name" => "required_if:payment_method,1",
            "account_holder_name" => "required_if:payment_method,1",
            "account_no" => "required_if:payment_method,1|unique:employees,bank_account_no,".$request->row_id,
            "branch_name" => "required_if:payment_method,1",
            "ewallet_type" => "required_if:payment_method,2",
            "ewallet_holder_name" => "required_if:payment_method,2",
            "ewallet_number" => "required_if:payment_method,2|unique:employees,wallet_no,".$request->row_id,
            "usdt_network" => "required_if:payment_method,3",
            "usdt_address" => "required_if:payment_method,3",
            // "password" => "nullable|confirmed|min:6",
        ]);

        try {
            $store = Employee::where('id', $request->row_id)->first();
            $store->login_id = $request->login_id;
            $store->affiliate_id = $request->affiliate_id;
            $store->emp_name = $request->name;
            $store->email = $request->email;
            $store->phone_number = $request->phone;
            $store->social_channel = $request->social_channel;
            $store->social_channel_details = $request->social_channel_details;
            $store->payment_method = $request->payment_method;
            if($request->payment_method == 1) {
                $store->bank_name = $request->bank_name;
                $store->bank_holder_name = $request->account_holder_name;
                $store->bank_account_no = $request->account_no;
                $store->branch_name = $request->branch_name;

                $store->wallet_type = '';
                $store->wallet_no = '';
                $store->wallet_holder_name = '';

                $store->usdt_network = '';
                $store->usdt_address = '';
            }elseif($request->payment_method ==2) {
                $store->wallet_type = $request->ewallet_type;
                $store->wallet_no = $request->ewallet_number;
                $store->wallet_holder_name = $request->ewallet_holder_name;

                $store->bank_name = '';
                $store->bank_holder_name = '';
                $store->bank_account_no = '';
                $store->branch_name = '';

                $store->usdt_network = '';
                $store->usdt_address = '';
            }else {
                $store->usdt_network = $request->usdt_network;
                $store->usdt_address = $request->usdt_address;

                $store->bank_name = '';
                $store->bank_holder_name = '';
                $store->bank_account_no = '';
                $store->branch_name = '';

                $store->wallet_type = '';
                $store->wallet_no = '';
                $store->wallet_holder_name = '';
            }
            $store->password = Hash::make('12345678');
            $store->save();
            if ($store->id) {
                return redirect()->route('commission.agent.list')->with("success", "Agent updated successfully");
            }
            return redirect()->back()->with("error", "Failed to update agent");
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function createImport(Request $request)
    {
        try {
            return view("admin.agent.agent-import");
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function importAgent(Request $request)
    {
        $validate = $this->validate($request, [
            'import_file' => 'required|mimes:xlsx,xls,csv',
        ]);
        set_time_limit(600);
        try {
            $data = Excel::toArray(new CommissionFileImport(), $request->file('import_file'));

            if ($data) {
                //validate employee already exists or not
                if ($users = ImportHelper::validateImportEmployee($data[0])) {
                    $implodeData = implode(",", $users);
                    return back()->with('error', "Given user ID {$implodeData} already exists. Please update file and try again.");
                }

                if (ImportHelper::importEmployee($data[0])) {
                    return redirect()->route('commission.agent.list')->with("success", "Agents imported successfully");
                }
                return redirect()->back()->with("error", "Failed to import agent");
            }

            return back()->with('error', 'Import failed');
        } catch (\Exception $e) {
            info($e->getMessage());
            return back()->with('error', 'Import failed');
        }
    }
}
