<?php

namespace App\Http\Controllers\Commission;

use App\Constants\StaticConstants;
use App\Http\Controllers\Controller;
use App\Mail\CommissionMail;
use App\Models\Adjustment;
use App\Models\AdjustmentPaid;
use App\Models\Affiliate;
use App\Models\CommissionEmployee;
use App\Models\CommissionPaid;
use App\Models\CommissionPaidCommission;
use App\Models\Employee;
use Barryvdh\DomPDF\Facade\Pdf;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Mail;

class CommissionController extends Controller
{
    // Pending Payout List View //
    public function pendingIndex(Request $request)
    {
        try {
            $search = !empty($request->search) ? $request->search : '';
            $listData = Employee::whereHas('availCommissions', function ($query) {
                return $query->where('paid_status', 0);
            })
                ->with(['availCommissions' => function ($query) {
                    return $query->withSum('commissions', 'total_commission')
                        ->withSum('commissions', 'due_commission')
                        ->withSum('commissions', 'paid_commission')
                        ->where('paid_status', 0);
                }])
                ->when($search != '', function ($query) use ($search) {
                    return $query->where('login_id', 'like', "%{$search}%");
                })
                ->where('commission_balance', '>', 0)
                ->paginate(10);

            return view("admin.available-commission-user.list", compact('listData'));
        } catch (\Exception $th) {
            Log::info($th);
        }
    }

    // Pending Payout Details View //
    public function unpaidView($id)
    {
        try {
            $paid_status = 0;
            $employee = Employee::where('id', $id)->first();
            $commissions = CommissionEmployee::with(['importInfo.period', 'importInfo.affiliate:id,name'])
                ->with(['importInfo.period.deposit.depositEmployees' => function ($query) use ($employee) {
                    return $query->where('employee_id', $employee->id);
                }])
                ->where('employee_id', $id)
                ->where('paid_status', 0)
                ->get();

            $total_amount = $commissions?->sum('due_commission');
            $adjustments = Adjustment::with('period:id,name')->where('login_id', $employee->login_id)->where('paid_status', 2)->get();
            $deductions = $adjustments?->where('adjustment_type', 1)->sum('adjustment_amount');
            $additions = $adjustments?->where('adjustment_type', 2)->sum('adjustment_amount');
            if ($deductions) {
                $total_amount -= $deductions;
            }
            if ($additions) {
                $total_amount += $additions;
            }

            return view("admin.available-commission-user.invoice", compact('employee', 'commissions', 'paid_status', 'total_amount', 'adjustments'));
        } catch (\Exception $th) {
            Log::info($th);
        }
    }

    public function downloadUnpaidInvoice($id)
    {
        try {
            $paid_status = 0;
            $paymentMethodDetails = '';
            $employee = Employee::where('id', $id)->first();
            $commissions = CommissionEmployee::with('importInfo.period')
                ->with(['importInfo.period.deposit.depositEmployees' => function ($query) use ($employee) {
                    return $query->where('employee_id', $employee->id);
                }])
                ->where('employee_id', $id)
                ->where('paid_status', 0)
                ->get();
            $total_amount = $commissions?->sum('due_commission');
            $adjustments = Adjustment::with('period:id,name')->where('login_id', $employee->login_id)->where('paid_status', 2)->get();
            $deductions = $adjustments?->where('adjustment_type', 1)->sum('adjustment_amount');
            $additions = $adjustments?->where('adjustment_type', 2)->sum('adjustment_amount');
            if ($deductions) {
                $total_amount -= $deductions;
            }
            if ($additions) {
                $total_amount += $additions;
            }

            if ($employee->payment_method == 1) {
                $paymentMethodDetails = "Bank name: {$employee->bank_name}, Branch name: {$employee->branch_name}, A/C holder name: {$employee->bank_holder_name}, A/C no: {$employee->bank_account_no}";
            } elseif ($employee->payment_method == 2) {
                $paymentMethodDetails = "Wallet type: {$employee->wallet_type}, Wallet holder name: {$employee->wallet_holder_name}, Wallet no: {$employee->wallet_no}";
            } elseif ($employee->payment_method == 3) {
                $paymentMethodDetails = "USDT network: {$employee->usdt_network}, USDT address: {$employee->usdt_address}";
            }

            $data = array(
                'login_id' => $employee->login_id,
                'emp_name' => $employee->emp_name,
                'payment_method_info' => $paymentMethodDetails,
                'paid_status' => $paid_status,
                'paid_at' => null,
                'paid_by' => null,
                'commissions' => $commissions,
                'adjustments' => $adjustments,
                'commissions_sum_total_commission' => $total_amount
            );
            $pdf = Pdf::loadView('admin.available-commission-user.invoice-template', $data);

            return $pdf->download($data['emp_name'] . '.pdf');
        } catch (\Exception $th) {
            Log::info($th);
        }
    }

    public function updateStatus($id)
    {
        try {
            DB::beginTransaction();

            $commEmployee = Employee::where('id', $id)->first();
            $commEmployees = CommissionEmployee::where('employee_id', $commEmployee->id)->where('paid_status', 0)->get();
            if ($commEmployees) {
                foreach ($commEmployees as $employee) {
                    $employee->paid_status = 1;
                    $employee->due_commission = 0;
                    $employee->paid_commission = $employee->total_commission;
                    $employee->paid_by = Auth::id();
                    $employee->paid_at = Carbon::now();
                    $employee->save();
                }
            }

            //update employee commission balance
            $commEmployee->commission_balance = 0;
            $commEmployee->save();

            //entry into paid table
            $paidStore = new CommissionPaid();
            $paidStore->employee_id = $id;
            $paidStore->paid_amount = $commEmployees->sum('total_commission');
            if ($commEmployee->payment_method == 1) {
                $paidStore->payment_method_info = "Bank name: {$commEmployee->bank_name}, Branch name: {$commEmployee->branch_name}, A/C holder name: {$commEmployee->bank_holder_name}, A/C no: {$commEmployee->bank_account_no}";
            } elseif ($commEmployee->payment_method == 2) {
                $paidStore->payment_method_info = "Wallet type: {$commEmployee->wallet_type}, Wallet holder name: {$commEmployee->wallet_holder_name}, Wallet no: {$commEmployee->wallet_no}";
            } elseif ($commEmployee->payment_method == 3) {
                $paidStore->payment_method_info = "USDT network: {$commEmployee->usdt_network}, USDT address: {$commEmployee->usdt_address}";
            } else {
                $paidStore->payment_method_info = "Not specified";
            }
            $paidStore->paid_at = Carbon::now();
            $paidStore->paid_by = Auth::id();
            $paidStore->save();
            if ($paidStore->id) {
                //store commission paid commissions table
                foreach ($commEmployees as $comemployee) {
                    $paidCommission = new CommissionPaidCommission();
                    $paidCommission->commission_paid_id = $paidStore->id;
                    $paidCommission->commission_employee_id = $comemployee->id;
                    $paidCommission->save();
                }
                //adjustment paid
                $adjustments = Adjustment::where('login_id', $commEmployee->login_id)->where('paid_status', 2)->get();
                foreach ($adjustments as $adjustment) {
                    $adjustmentPaid = new AdjustmentPaid();
                    $adjustmentPaid->adjustment_id = $adjustment->id;
                    $adjustmentPaid->commission_paid_id = $paidStore->id;
                    $adjustmentPaid->calculation_type = $adjustment->adjustment_type;
                    $adjustmentPaid->amount = $adjustment->adjustment_amount;
                    $adjustmentPaid->save();
                }

                // Update all adjustments' paid_status to 1
                Adjustment::where('login_id', $commEmployee->login_id)
                    ->where('paid_status', 2)
                    ->update(['paid_status' => 1]);
                if($commEmployee->email) {
                    self::sendPaidMail($paidStore->id);
                }
            }

            DB::commit();
            return redirect()->back()->with("success", "Paid successfully");
        } catch (\Exception $e) {
            DB::rollBack();
            info($e->getMessage());
            return redirect()->back()->with("error", "Paid failed");
        }
    }

    // Paid Payout List View //
    public function paidIndex(Request $request)
    {
        try {
            $search = !empty($request->search) ? $request->search : '';
            $listData = CommissionPaid::with('paidBy:id,name')
                ->with('employee:id,emp_name,login_id')
                ->withSum('additionAdjustments', 'amount')
                ->withSum('deductionAdjustments', 'amount')
                ->when($search != '', function ($query) use ($search) {
                    return $query->whereHas('employee', function ($query) use ($search) {
                        return $query->where('emp_name', 'like', "%{$search}%");
                    });
                })
                ->orderBy('id', 'desc')
                ->paginate(10);

            return view("admin.paid-commission-user.list", compact('listData'));
        } catch (\Exception $th) {
            Log::info($th);
        }
    }

    // Paid Payout Details View //
    public function paidView($id)
    {
        try {
            $paid_status = 1;
            $paidCommission = CommissionPaid::where('id', $id)->first();
            $employee = Employee::where('id', $paidCommission->employee_id)->first();
            $paidCommissionCommissions = CommissionPaidCommission::where(['commission_paid_id' => $paidCommission->id])->get()->pluck('commission_employee_id');
            $commissions = CommissionEmployee::with(['importInfo.period', 'importInfo.affiliate:id,name'])
                ->with(['importInfo.period.deposit.depositEmployees' => function ($query) use ($employee) {
                    return $query->where('employee_id', $employee->id);
                }])
                ->where('employee_id', $employee->id)
                ->whereIn('id', $paidCommissionCommissions)
                ->where('paid_status', 1)
                ->get();
            $totalPaid = $paidCommission->paid_amount;
            $adjustments = AdjustmentPaid::with('adjustmentInfo.period')
                ->where('commission_paid_id', $paidCommission->id)
                ->get();
            $deductions = $adjustments?->where('calculation_type', 1)->sum('amount');
            $additions = $adjustments?->where('calculation_type', 2)->sum('amount');
            if ($deductions) {
                $totalPaid -= $deductions;
            }
            if ($additions) {
                $totalPaid += $additions;
            }

            return view("admin.paid-commission-user.invoice", compact('employee', 'commissions', 'paid_status', 'paidCommission', 'adjustments', 'totalPaid'));
        } catch (\Exception $th) {
            Log::info($th);
        }
    }

    public function downloadPaidInvoice($id)
    {
        try {
            $paid_status = 1;
            $paidCommission = CommissionPaid::where('id', $id)->first();
            $employee = Employee::where('id', $paidCommission->employee_id)->first();
            $paidCommissionCommissions = CommissionPaidCommission::where(['commission_paid_id' => $paidCommission->id])->get()->pluck('commission_employee_id');
            $commissions = CommissionEmployee::with('importInfo.period')
                ->with(['importInfo.period.deposit.depositEmployees' => function ($query) use ($employee) {
                    return $query->where('employee_id', $employee->id);
                }])
                ->where('employee_id', $employee->id)
                ->whereIn('id', $paidCommissionCommissions)
                ->where('paid_status', 1)
                ->get();

            $totalPaid = $paidCommission->paid_amount;
            $adjustments = AdjustmentPaid::with('adjustmentInfo.period')
                ->where('commission_paid_id', $paidCommission->id)
                ->get();
            $deductions = $adjustments?->where('calculation_type', 1)->sum('amount');
            $additions = $adjustments?->where('calculation_type', 2)->sum('amount');
            if ($deductions) {
                $totalPaid -= $deductions;
            }
            if ($additions) {
                $totalPaid += $additions;
            }

            $data = array(
                'emp_name' => $employee->emp_name,
                'payment_method_info' => $paidCommission->payment_method_info,
                'paid_status' => $paid_status,
                'paid_at' => $paidCommission->paid_at,
                'paid_by' => $paidCommission->paidBy->name,
                'commissions' => $commissions,
                'adjustments' => $adjustments,
                'commissions_sum_total_commission' => $totalPaid
            );
            $pdf = Pdf::loadView('admin.paid-commission-user.invoice-template', $data);

            return $pdf->download($data['emp_name'] . '.pdf');
        } catch (\Exception $th) {
            Log::info($th);
        }
    }

    public function paymentRequestIndex(Request $request)
    {
        try {
            $search = !empty($request->search) ? $request->search : '';
            $listData = Employee::whereHas('availCommissions', function ($query) {
                return $query->where('paid_status', 0);
            })
                ->with(['availCommissions' => function ($query) {
                    return $query->withSum('commissions', 'total_commission')
                        ->withSum('commissions', 'due_commission')
                        ->withSum('commissions', 'paid_commission')
                        ->where('paid_status', 0);
                }])
                ->withSum('additionAdjustments', 'adjustment_amount')
                ->withSum('deductionAdjustments', 'adjustment_amount')
                ->when($search != '', function ($query) use ($search) {
                    return $query->where('emp_name', 'like', "%{$search}%");
                })
                ->where('commission_balance', '>=', StaticConstants::PAYOUT_MIN_AMOUNT)
                ->get();

            return view("admin.payment-request.list", compact('listData'));
        } catch (\Exception $th) {
            Log::info($th);
        }
    }


    public function paymentRequestDownload()
    {
        try {
            $listData = Employee::whereHas('availCommissions', function ($query) {
                return $query->where('paid_status', 0);
            })
                ->with(['availCommissions' => function ($query) {
                    return $query->withSum('commissions', 'total_commission')
                        ->withSum('commissions', 'due_commission')
                        ->withSum('commissions', 'paid_commission')
                        ->where('paid_status', 0)
                        ->with('importInfo.period');
                }])
                ->withSum('additionAdjustments', 'adjustment_amount')
                ->withSum('deductionAdjustments', 'adjustment_amount')
                ->with(['adjustments' => function ($query) {
                    return $query->where('paid_status', 2)
                        ->with('period');
                }])
                ->where('commission_balance', '>=', StaticConstants::PAYOUT_MIN_AMOUNT)
                ->get();

            $pdf = PDF::loadView('admin.payment-request.download-invoice-list', ['listData' => $listData]);
            return $pdf->download('listData' . '.pdf');

        } catch (\Exception $th) {
            Log::info($th);
        }
    }

    public function paymentRequestView($id)
    {
        try {
            $paid_status = 0;
            $employee = Employee::where('id', $id)->first();
            $commissions = CommissionEmployee::with(['importInfo.period', 'importInfo.affiliate:id,name'])
                ->with(['importInfo.period.deposit.depositEmployees' => function ($query) use ($employee) {
                    return $query->where('employee_id', $employee->id);
                }])
                ->where('employee_id', $id)
                ->where('paid_status', 0)
                ->get();
            $total_amount = $commissions?->sum('due_commission');
            $adjustments = Adjustment::with('period:id,name')->where('login_id', $employee->login_id)->where('paid_status', 2)->get();
            $deductions = $adjustments?->where('adjustment_type', 1)->sum('adjustment_amount');
            $additions = $adjustments?->where('adjustment_type', 2)->sum('adjustment_amount');
            if ($deductions) {
                $total_amount -= $deductions;
            }
            if ($additions) {
                $total_amount += $additions;
            }

            return view("admin.payment-request.invoice", compact('employee', 'commissions', 'paid_status', 'total_amount', 'adjustments'));
        } catch (\Exception $th) {
            Log::info($th);
        }
    }

    public function releasePayment(Request $request)
    {
        try {
            DB::beginTransaction();

            $empIDs = Employee::whereHas('availCommissions', function ($query) {
                return $query->where('paid_status', 0);
            })
                ->where('commission_balance', '>=', StaticConstants::PAYOUT_MIN_AMOUNT)
                ->get()->pluck('id');

            foreach ($empIDs as $empID) {
                $commEmployee = Employee::where('id', $empID)->first();
                $commEmployees = CommissionEmployee::where('employee_id', $commEmployee->id)->where('paid_status', 0)->get();
                if ($commEmployees) {
                    foreach ($commEmployees as $employee) {
                        $employee->paid_status = 1;
                        $employee->due_commission = 0;
                        $employee->paid_commission = $employee->total_commission;
                        $employee->paid_by = Auth::id();
                        $employee->paid_at = Carbon::now();
                        $employee->save();
                    }
                }

                //update employee commission balance
                $commEmployee->commission_balance = 0;
                $commEmployee->save();

                //entry into paid table
                $paidStore = new CommissionPaid();
                $paidStore->employee_id = $empID;
                $paidStore->paid_amount = $commEmployees->sum('total_commission');
                if ($commEmployee->payment_method == 1) {
                    $paidStore->payment_method_info = "Bank name: {$commEmployee->bank_name}, Branch name: {$commEmployee->branch_name}, A/C holder name: {$commEmployee->bank_holder_name}, A/C no: {$commEmployee->bank_account_no}";
                } elseif ($commEmployee->payment_method == 2) {
                    $paidStore->payment_method_info = "Wallet type: {$commEmployee->wallet_type}, Wallet holder name: {$commEmployee->wallet_holder_name}, Wallet no: {$commEmployee->wallet_no}";
                } elseif ($commEmployee->payment_method == 3) {
                    $paidStore->payment_method_info = "USDT network: {$commEmployee->usdt_network}, USDT address: {$commEmployee->usdt_address}";
                } else {
                    $paidStore->payment_method_info = "Not specified";
                }
                $paidStore->paid_at = Carbon::now();
                $paidStore->paid_by = Auth::id();
                $paidStore->save();
                if ($paidStore->id) {
                    //store commission paid commissions table
                    foreach ($commEmployees as $comemployee) {
                        $paidCommission = new CommissionPaidCommission();
                        $paidCommission->commission_paid_id = $paidStore->id;
                        $paidCommission->commission_employee_id = $comemployee->id;
                        $paidCommission->save();
                    }

                    //adjustment paid
                    $adjustments = Adjustment::where('login_id', $commEmployee->login_id)->where('paid_status', 2)->get();
                    foreach ($adjustments as $adjustment) {
                        $adjustmentPaid = new AdjustmentPaid();
                        $adjustmentPaid->adjustment_id = $adjustment->id;
                        $adjustmentPaid->commission_paid_id = $paidStore->id;
                        $adjustmentPaid->calculation_type = $adjustment->adjustment_type;
                        $adjustmentPaid->amount = $adjustment->adjustment_amount;
                        $adjustmentPaid->save();
                    }

                    // Update all adjustments' paid_status to 1
                    Adjustment::where('login_id', $commEmployee->login_id)
                        ->where('paid_status', 2)
                        ->update(['paid_status' => 1]);

                    if($commEmployee->email) {
                        self::sendPaidMail($paidStore->id);
                    }
                }
            }

            DB::commit();

            return redirect()->back()->with("success", "Paid successfully");
        } catch (\Exception $e) {
            DB::rollBack();
            info($e->getMessage());
            return redirect()->back()->with("error", "Paid failed");
        }
    }

    private function sendPaidMail($commissionPaidId)
    {
        try {
            $paid_status = 1;
            $paidCommission = CommissionPaid::where('id', $commissionPaidId)->first();
            $employee = Employee::where('id', $paidCommission->employee_id)->first();
            $paidCommissionCommissions = CommissionPaidCommission::where(['commission_paid_id' => $paidCommission->id])->get()->pluck('commission_employee_id');
            $commissions = CommissionEmployee::with('importInfo.period')
                ->with(['importInfo.period.deposit.depositEmployees' => function ($query) use ($employee) {
                    return $query->where('employee_id', $employee->id);
                }])
                ->where('employee_id', $employee->id)
                ->whereIn('id', $paidCommissionCommissions)
                ->where('paid_status', 1)
                ->get();

            $totalPaid = $paidCommission->paid_amount;
            $adjustments = AdjustmentPaid::with('adjustmentInfo.period')
                ->where('commission_paid_id', $paidCommission->id)
                ->get();
            $deductions = $adjustments?->where('calculation_type', 1)->sum('amount');
            $additions = $adjustments?->where('calculation_type', 2)->sum('amount');
            if ($deductions) {
                $totalPaid -= $deductions;
            }
            if ($additions) {
                $totalPaid += $additions;
            }

            $data = collect(array(
                'emp_name' => $employee->emp_name,
                'payment_method_info' => $paidCommission->payment_method_info,
                'paid_status' => $paid_status,
                'paid_at' => $paidCommission->paid_at,
                'paid_by' => $paidCommission->paidBy->name,
                'commissions' => $commissions,
                'adjustments' => $adjustments,
                'commissions_sum_total_commission' => $totalPaid
            ));

            Mail::to($employee->email)->queue(new CommissionMail($data, view: 'email.paid-invoice-template'));

        } catch (\Exception $th) {
            Log::info($th);
        }
    }
}
