<?php

namespace App\Http\Controllers\Mail;

use App\Http\Controllers\Controller;
use App\Mail\CommissionMail;
use App\Models\Adjustment;
use App\Models\CommissionEmployee;
use App\Models\Employee;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;

class MailController extends Controller
{
    public function sendPendingPayoutMail(Request $request)
    {
        try {
            Employee::whereHas('availCommissions', function ($query) {
                return $query->where('paid_status', 0);
            })
                ->with(['availCommissions' => function ($query) {
                    return $query->withSum('commissions', 'total_commission')
                        ->withSum('commissions', 'due_commission')
                        ->withSum('commissions', 'paid_commission')
                        ->where('paid_status', 0);
                }])
                ->where('commission_balance', '>', 0)
                ->chunk(100, function ($employees) {
                    foreach ($employees as $employee) {
                        if ($employee->email) {
                            self::sendPendingMail($employee);
                        }
                    }
                });

            return back()->with('success', 'Pending payout emails sent successfully.');
        } catch (\Exception $e) {
            info($e->getMessage());
            return back()->with('error', $e->getMessage());
        }
    }

    private function sendPendingMail($employee)
    {
        $paymentMethodDetails = '';
        $commissions = CommissionEmployee::with('importInfo.period')
            ->with(['importInfo.period.deposit.depositEmployees' => function ($query) use ($employee) {
                return $query->where('employee_id', $employee->id);
            }])
            ->where('employee_id', $employee->id)
            ->where('paid_status', 0)
            ->get();
        $total_amount = $commissions?->sum('due_commission');
        $adjustments = Adjustment::with('period:id,name')->where('login_id', $employee->login_id)->where('paid_status', 2)->get();
        $deductions = $adjustments?->where('adjustment_type', 1)->sum('adjustment_amount');
        $additions = $adjustments?->where('adjustment_type', 2)->sum('adjustment_amount');
        if ($deductions) {
            $total_amount -= $deductions;
        }
        if ($additions) {
            $total_amount += $additions;
        }

        if ($employee->payment_method == 1) {
            $paymentMethodDetails = "Bank name: {$employee->bank_name}, Branch name: {$employee->branch_name}, A/C holder name: {$employee->bank_holder_name}, A/C no: {$employee->bank_account_no}";
        } elseif ($employee->payment_method == 2) {
            $paymentMethodDetails = "Wallet type: {$employee->wallet_type}, Wallet holder name: {$employee->wallet_holder_name}, Wallet no: {$employee->wallet_no}";
        } elseif ($employee->payment_method == 3) {
            $paymentMethodDetails = "USDT network: {$employee->usdt_network}, USDT address: {$employee->usdt_address}";
        }

        $data = collect(array(
            'login_id' => $employee->login_id,
            'emp_name' => $employee->emp_name,
            'payment_method_info' => $paymentMethodDetails,
            'paid_status' => 0,
            'paid_at' => null,
            'paid_by' => null,
            'commissions' => $commissions,
            'adjustments' => $adjustments,
            'commissions_sum_total_commission' => $total_amount
        ));

        Mail::to($employee->email)->queue(new CommissionMail($data, view: 'email.pending-invoice-template'));
    }
}
