<?php

namespace App\Http\Controllers\Report;

use App\Exports\CommissionReportExport;
use App\Exports\CustomEmployeeReportExport;
use App\Http\Controllers\Controller;
use App\Models\Adjustment;
use App\Models\Affiliate;
use App\Models\CommissionEmployee;
use App\Models\DepositEmployee;
use App\Models\Employee;
use App\Models\Period;
use Illuminate\Http\Request;
use Maatwebsite\Excel\Facades\Excel;

class ReportController extends Controller
{
    public function commissionReport(Request $request)
    {
        $startDate = $request->start_date ? date('Y-m-d', strtotime($request->start_date)) : null;
        $endDate = $request->end_date ? date('Y-m-d', strtotime($request->end_date)) : null;
        $agentId = $request->agent_id ?? null;
        $affiliateId = $request->affiliate_id ?? null;
        $paymentStatus = $request->payment_status == 'all' ? null : ($request->payment_status == 2 ? 0 : $request->payment_status);
        $depositRange = $request->deposit_range ? $request->deposit_range == 1 ? '<=' : '>=' : null;
        $depositRangeValue = $request->deposit_range_value ?? null;
        $ftdRange = $request->ftd_range ? $request->ftd_range == 1 ? '<=' : '>=' : null;
        $ftdRangeValue = $request->ftd_range_value ?? null;
        $activeMemberRange = $request->active_member_range ? $request->active_member_range == 1 ? '<=' : '>=' : null;
        $activeMemberRangeValue = $request->active_member_range_value ?? null;
        $commissionRange = $request->commission_range ? $request->commission_range == 1 ? '<=' : '>=' : null;
        $commissionRangeValue = $request->commission_range_value ?? null;

        $listData = array();
        if ($startDate && $endDate) {
            $periods = Period::where('start_date', '>=', $startDate)
                ->where('end_date', '<=', $endDate)
                ->get()->pluck('id');
            if (count($periods) > 0) {
                $listData = Employee::whereHas('availCommissions', function ($query) use ($paymentStatus, $periods) {
                    if ($paymentStatus !== null) {
                        $query->where('paid_status', $paymentStatus);
                    }
                    $query->whereHas('importInfo', function ($query) use ($periods) {
                        return $query->whereIn('period_id', $periods);
                    });
                })
                    ->with('affiliate:id,name')
                    ->with(['availCommissions' => function ($query) use ($paymentStatus, $periods) {
                        if ($paymentStatus !== null) {
                            $query->where('paid_status', $paymentStatus);
                        }
                        $query->whereHas('importInfo', function ($query) use ($periods) {
                            return $query->whereIn('period_id', $periods);
                        });
                    }])
                    ->with(['deposits' => function ($query) use ($periods) {
                        return $query->whereHas('importInfo', function ($query) use ($periods) {
                            return $query->whereIn('period_id', $periods);
                        });
                    }])
                    ->when($depositRangeValue != null, function ($query) use ($depositRange, $depositRangeValue, $periods) {
                        return $query->withSum(['deposits as dp_amount' => function ($query) use ($periods) {
                            $query->whereHas('importInfo', function ($query) use ($periods) {
                                return $query->whereIn('period_id', $periods);
                            });
                        }], 'plus_minus')->having('dp_amount', $depositRange, $depositRangeValue);
                    })
                    ->when($ftdRangeValue != null, function ($query) use ($ftdRange, $ftdRangeValue, $periods) {
                        return $query->withCount(['deposits as ftd_count' => function ($query) use ($periods) {
                            $query->where('first_deposit', '!=', 'N')
                                ->whereHas('importInfo', function ($query) use ($periods) {
                                    return $query->whereIn('period_id', $periods);
                                });
                        }])->having('ftd_count', $ftdRange, $ftdRangeValue);
                    })
                    ->when($activeMemberRangeValue != null, function ($query) use ($activeMemberRange, $activeMemberRangeValue, $periods, $paymentStatus) {
                        return $query->withSum([
                            'availCommissions as active_members' => function ($query) use ($periods, $paymentStatus) {
                                if ($paymentStatus !== null) {
                                    $query->where('paid_status', $paymentStatus);
                                }
                                $query->whereHas('importInfo', function ($query) use ($periods) {
                                    return $query->whereIn('period_id', $periods);
                                });
                            }
                        ], 'active_member')
                            ->having('active_members', $activeMemberRange, $activeMemberRangeValue);
                    })
                    ->when($commissionRangeValue != null, function ($query) use ($commissionRange, $commissionRangeValue, $periods, $paymentStatus) {
                        return $query->withSum(['availCommissions as avail_total_commission' => function ($query) use ($periods, $paymentStatus) {
                            if ($paymentStatus !== null) {
                                $query->where('paid_status', $paymentStatus);
                            }
                            $query->whereHas('importInfo', function ($query) use ($periods) {
                                return $query->whereIn('period_id', $periods);
                            });
                        }], 'total_commission')->having('avail_total_commission', $commissionRange, $commissionRangeValue);
                    })
                    ->when($agentId != null, function ($query) use ($agentId) {
                        return $query->where('login_id', $agentId);
                    })
                    ->when($affiliateId != null, function ($query) use ($affiliateId) {
                        return $query->where('affiliate_id', $affiliateId);
                    })
                    ->get(['id', 'login_id', 'affiliate_id', 'emp_name', 'email', 'phone_number']);
            }
        }

        $affiliates = Affiliate::all();
        return view("admin.payout-report.list", compact('affiliates', 'listData'));
    }

    public function commissionReportExport(Request $request)
    {
        $startDate = $request->start_date ? date('Y-m-d', strtotime($request->start_date)) : null;
        $endDate = $request->end_date ? date('Y-m-d', strtotime($request->end_date)) : null;
        $agentId = $request->agent_id ?? null;
        $affiliateId = $request->affiliate_id ?? null;
        $paymentStatus = $request->payment_status == 'all' ? null : ($request->payment_status == 2 ? 0 : $request->payment_status);
        $depositRange = $request->deposit_range ? $request->deposit_range == 1 ? '<=' : '>=' : null;
        $depositRangeValue = $request->deposit_range_value ?? null;
        $ftdRange = $request->ftd_range ? $request->ftd_range == 1 ? '<=' : '>=' : null;
        $ftdRangeValue = $request->ftd_range_value ?? null;
        $activeMemberRange = $request->active_member_range ? $request->active_member_range == 1 ? '<=' : '>=' : null;
        $activeMemberRangeValue = $request->active_member_range_value ?? null;
        $commissionRange = $request->commission_range ? $request->commission_range == 1 ? '<=' : '>=' : null;
        $commissionRangeValue = $request->commission_range_value ?? null;

        $exportData = array();
        $listData = array();
        if ($startDate && $endDate) {

            $periods = Period::where('start_date', '>=', $startDate)
                ->where('end_date', '<=', $endDate)
                ->get()->pluck('id');
            if (count($periods) > 0) {
                $listData = Employee::whereHas('availCommissions', function ($query) use ($paymentStatus, $periods) {
                    if ($paymentStatus !== null) {
                        $query->where('paid_status', $paymentStatus);
                    }
                    $query->whereHas('importInfo', function ($query) use ($periods) {
                        return $query->whereIn('period_id', $periods);
                    });
                })
                    ->with('affiliate:id,name')
                    ->with(['availCommissions' => function ($query) use ($paymentStatus, $periods) {
                        if ($paymentStatus !== null) {
                            $query->where('paid_status', $paymentStatus);
                        }
                        $query->whereHas('importInfo', function ($query) use ($periods) {
                            return $query->whereIn('period_id', $periods);
                        });
                    }])
                    ->with(['deposits' => function ($query) use ($periods) {
                        return $query->whereHas('importInfo', function ($query) use ($periods) {
                            return $query->whereIn('period_id', $periods);
                        });
                    }])
                    ->when($depositRangeValue != null, function ($query) use ($depositRange, $depositRangeValue, $periods) {
                        return $query->withSum(['deposits as dp_amount' => function ($query) use ($periods) {
                            $query->whereHas('importInfo', function ($query) use ($periods) {
                                return $query->whereIn('period_id', $periods);
                            });
                        }], 'plus_minus')->having('dp_amount', $depositRange, $depositRangeValue);
                    })
                    ->when($ftdRangeValue != null, function ($query) use ($ftdRange, $ftdRangeValue, $periods) {
                        return $query->withCount(['deposits as ftd_count' => function ($query) use ($periods) {
                            $query->where('first_deposit', '!=', 'N')
                                ->whereHas('importInfo', function ($query) use ($periods) {
                                    return $query->whereIn('period_id', $periods);
                                });
                        }])->having('ftd_count', $ftdRange, $ftdRangeValue);
                    })
                    ->when($activeMemberRangeValue != null, function ($query) use ($activeMemberRange, $activeMemberRangeValue, $periods, $paymentStatus) {
                        return $query->withSum([
                            'availCommissions as active_members' => function ($query) use ($periods, $paymentStatus) {
                                if ($paymentStatus !== null) {
                                    $query->where('paid_status', $paymentStatus);
                                }
                                $query->whereHas('importInfo', function ($query) use ($periods) {
                                    return $query->whereIn('period_id', $periods);
                                });
                            }
                        ], 'active_member')
                            ->having('active_members', $activeMemberRange, $activeMemberRangeValue);
                    })
                    ->when($commissionRangeValue != null, function ($query) use ($commissionRange, $commissionRangeValue, $periods, $paymentStatus) {
                        return $query->withSum(['availCommissions as avail_total_commission' => function ($query) use ($periods, $paymentStatus) {
                            if ($paymentStatus !== null) {
                                $query->where('paid_status', $paymentStatus);
                            }
                            $query->whereHas('importInfo', function ($query) use ($periods) {
                                return $query->whereIn('period_id', $periods);
                            });
                        }], 'total_commission')->having('avail_total_commission', $commissionRange, $commissionRangeValue);
                    })
                    ->when($agentId != null, function ($query) use ($agentId) {
                        return $query->where('login_id', $agentId);
                    })
                    ->when($affiliateId != null, function ($query) use ($affiliateId) {
                        return $query->where('affiliate_id', $affiliateId);
                    })
                    ->get(['id', 'login_id', 'affiliate_id', 'emp_name', 'email', 'phone_number']);
            }
        }

        if (count($listData) > 0) {
            foreach ($listData as $key => $data) {
                $tempData = array(
                    ($key + 1),
                    $data->affiliate->name ?? '',
                    $data->login_id,
                    $data->emp_name,
                    $data->email,
                    $data->phone_number,
                    $data?->deposits?->count() ?? 0,
                    $data?->deposits?->where('first_deposit', '!=', 'N')->count() ?? 0,
                    $data?->deposits?->sum('plus_minus') ?? 0,
                    $data?->availCommissions?->sum('active_member') ?? 0,
                    $data?->availCommissions?->sum('member_WL') ?? 0,
                    $data?->availCommissions?->sum('total_commission') ?? 0,
                    $data?->availCommissions?->where('paid_status', 0)->sum('due_commission') ?? 0,
                    $data?->availCommissions?->where('paid_status', 1)->sum('paid_commission') ?? 0
                );
                $exportData[] = $tempData;
            }
        }

        return Excel::download(new CustomEmployeeReportExport(collect($exportData)), 'agent-report.xlsx');
    }


    /*.................... report tab ....................*/
    public function overviewReportTab(Request $request)
    {
        $agentId = $request->agent_id ?? null;
        $agentData = Employee::with('affiliate')
            ->withSum(['availCommissions' => function ($query) {
                return $query->where('paid_status', 1);
            }], 'paid_commission')
            ->where('login_id', $agentId)->first();

        return view("admin.report-tab.overview-report", compact('agentData'));
    }

    public function commissionReportTab(Request $request)
    {
        $startDate = $request->start_date ? date('Y-m-d', strtotime($request->start_date)) : null;
        $endDate = $request->end_date ? date('Y-m-d', strtotime($request->end_date)) : null;
        $paymentStatus = $request->payment_status == 'all' ? null : ($request->payment_status == 2 ? 0 : $request->payment_status);
        $agentId = $request->agent_id ?? null;
        $data = array();
        if (!empty($startDate) && !empty($endDate) && !empty($agentId)) {
            $periods = Period::where('start_date', '>=', $startDate)
                ->where('end_date', '<=', $endDate)
                ->get()->pluck('id');
            if (count($periods) > 0) {
                $data = CommissionEmployee::with('employeeInfo.affiliate')
                    ->whereHas('importInfo', function ($query) use ($periods) {
                        return $query->whereIn('period_id', $periods);
                    })
                    ->with('importInfo.period:id,name')
                    ->when($paymentStatus != null, function ($query) use ($paymentStatus) {
                        return $query->where('paid_status', $paymentStatus);
                    })
                    ->where('ag_login_id', $agentId)
                    ->get();

            }
        }

        return view("admin.report-tab.commission-report", compact('data'));
    }

    public function commissionReportTabExport(Request $request)
    {
        $exportData = array();
        $startDate = $request->start_date ? date('Y-m-d', strtotime($request->start_date)) : null;
        $endDate = $request->end_date ? date('Y-m-d', strtotime($request->end_date)) : null;
        $paymentStatus = $request->payment_status == 'all' ? null : ($request->payment_status == 2 ? 0 : $request->payment_status);
        $agentId = $request->agent_id ?? null;
        $data = array();
        if (!empty($startDate) && !empty($endDate) && !empty($agentId)) {
            $periods = Period::where('start_date', '>=', $startDate)
                ->where('end_date', '<=', $endDate)
                ->get()->pluck('id');
            if (count($periods) > 0) {
                $data = CommissionEmployee::with('employeeInfo.affiliate')
                    ->whereHas('importInfo', function ($query) use ($periods) {
                        return $query->whereIn('period_id', $periods);
                    })
                    ->with('importInfo.period:id,name')
                    ->when($paymentStatus != null, function ($query) use ($paymentStatus) {
                        return $query->where('paid_status', $paymentStatus);
                    })
                    ->where('ag_login_id', $agentId)
                    ->get();

            }
        }

        if (count($data) > 0) {
            foreach ($data as $key => $comm) {
                $tempData = array(
                    ($key + 1),
                    $comm?->employeeInfo?->affiliate->name ?? '',
                    $comm?->employeeInfo->login_id,
                    $comm?->employeeInfo->emp_name,
                    $comm?->employeeInfo->email,
                    $comm?->employeeInfo->phone_number,
                    $comm?->importInfo->period->name,
                    $comm?->due_commission,
                    $comm?->paid_commission
                );
                $exportData[] = $tempData;
            }
        }

        return Excel::download(new CommissionReportExport(collect($exportData)), 'commission-report.xlsx');
    }

    public function depositReportTab(Request $request)
    {
        $startDate = $request->start_date ? date('Y-m-d', strtotime($request->start_date)) : null;
        $endDate = $request->end_date ? date('Y-m-d', strtotime($request->end_date)) : null;
        $agentId = $request->agent_id ?? null;
        $data = array();
        if (!empty($startDate) && !empty($endDate) && !empty($agentId)) {
            $periods = Period::where('start_date', '>=', $startDate)
                ->where('end_date', '<=', $endDate)
                ->get()->pluck('id');
            if (count($periods) > 0) {
                $data = DepositEmployee::with('employeeInfo.affiliate')
                    ->whereHas('importInfo', function ($query) use ($periods) {
                        return $query->whereIn('period_id', $periods);
                    })
                    ->with('importInfo.period:id,name')
                    ->where('ag_login_id', $agentId)
                    ->get();
            }
        }

        return view("admin.report-tab.deposit-report", compact('data'));
    }

    public function adjustmentReportTab(Request $request)
    {
        $startDate = $request->start_date ? date('Y-m-d', strtotime($request->start_date)) : null;
        $endDate = $request->end_date ? date('Y-m-d', strtotime($request->end_date)) : null;
        $adjustmentType = $request->adjustment_type == 'all' ? null : $request->adjustment_type;
        $agentId = $request->agent_id ?? null;

        $data = array();
        if (!empty($startDate) && !empty($endDate) && !empty($agentId)) {
            $periods = Period::where('start_date', '>=', $startDate)
                ->where('end_date', '<=', $endDate)
                ->get()->pluck('id');
            if (count($periods) > 0) {
                $data = Adjustment::with('agent.affiliate')
                    ->whereIn('period_id', $periods)
                    ->when($adjustmentType != null, function ($query) use ($adjustmentType) {
                        return $query->where('adjustment_type', $adjustmentType);
                    })
                    ->with('period:id,name')
                    ->where('login_id', $agentId)
                    ->get();
            }
        }

        return view("admin.report-tab.adjustment-report", compact('data'));
    }
}
