<?php

namespace App\Http\Controllers\System\Role;

use App\Http\Controllers\Controller;
use App\Models\Role as ModelsRole;
use App\Models\RoleHasPermission;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;

class RoleController extends Controller
{
    public function roleList(Request $request)
    {
        try {
            $search = !empty($request->search) ? $request->search : '';
            $roles = ModelsRole::with(['createdBy:id,name', 'updatedBy:id,name'])->when($search != '', function ($query) use ($search) {
                return $query->where('name', 'like', "%{$search}%");
            })
                ->where('id', '!=', 1)
                ->orderBy('id', 'desc')
                ->paginate(10);
            return view("admin.system.role.list", compact('roles'));
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function createRole(Request $request)
    {
        try {
            $permissions = Permission::all();
            return view("admin.system.role.create", compact('permissions'));
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function submitCreateRole(Request $request)
    {
        $validate = $this->validate($request, [
            'role_name' => 'required|unique:roles,name',
            'permissions' => 'required|array'
        ]);

        try {
            $store = new Role();
            $store->name = $request->role_name;
            $store->save();
            if ($store->id) {
                $store->givePermissionTo(array_map('intval', $request->permissions));
                return redirect()->route("system.role.list")->with("success", "Role created successfully");
            }
            return redirect()->back()->with("error", "Failed to create role");
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function viewRole($id)
    {
        try {
            $role = ModelsRole::find($id);
            $role_permissions = RoleHasPermission::where('role_id', $role->id)->get()->pluck('permission_id')->toArray();
            $permissions = Permission::all();
            return view("admin.system.role.edit", compact('permissions', 'role', 'role_permissions'));
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function updateRole(Request $request)
    {
        $validate = $this->validate($request, [
            'role_name' => 'required|unique:roles,name,' . $request->id,
            'permissions' => 'required|array'
        ]);

        try {
            $update = Role::where('id', $request->id)->first();
            $update->name = $request->role_name;
            $update->save();
            if ($update->id) {
                $update->syncPermissions(array_map('intval', $request->permissions));
                return redirect()->route("system.role.list")->with("success", "Role updated successfully");
            }
            return redirect()->back()->with("error", "Failed to create role");
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }
}
