<?php

namespace App\Http\Controllers\System\User;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;
use Spatie\Permission\Models\Role;

class UserController extends Controller
{
    public function userList(Request $request)
    {
        try {
            $search = !empty($request->search) ? $request->search : '';
            $users = User::with(['createdBy:id,name', 'updatedBy:id,name', 'role:id,name'])
                ->when($search != '', function ($query) use ($search) {
                    return $query->where('name', 'like', "%{$search}%");
                })
                ->whereNotIn('id', [1, Auth::id()])
                ->where('user_type', 0)
                ->paginate(10);
            return view("admin.system.user.list", compact("users"));
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function createUser(Request $request)
    {
        try {
            $roles = Role::where('id', '!=', 1)->get();
            return view("admin.system.user.create", compact('roles'));
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function submitCreateUser(Request $request)
    {
        $validator = $this->validate($request, [
            "name" => "required",
            "email" => "required|unique:users,email",
            "phone" => "nullable",
            "password" => "required|confirmed",
            "role" => "required"
        ]);

        try {
            DB::beginTransaction();
            $store = new User();
            $store->name = $request->name;
            $store->email = $request->email;
            $store->phone = $request->phone;
            $store->password = Hash::make($request->password);
            $store->role_id = $request->role;
            $store->save();
            if ($store->id) {
                $role = Role::findById($store->role_id);
                $store->assignRole($role);
                DB::commit();
                return redirect()->route('system.user.list')->with("success", "User added successfully");
            }
            return redirect()->back()->with("error", "Failed to add user");
        } catch (\Throwable $th) {
            DB::rollBack();
            Log::info($th);
        }
    }

    public function viewUser($id)
    {
        try {
            $user = User::find($id);
            $roles = Role::where('id', '!=', 1)->get();
            return view("admin.system.user.edit", compact('user', 'roles'));
        } catch (\Throwable $th) {
            Log::info($th);
        }
    }

    public function updateUser(Request $request)
    {
        $validator = $this->validate($request, [
            "name" => "required",
            "email" => "required|unique:users,email," . $request->id,
            "phone" => "nullable",
            "password" => "nullable|confirmed",
            "role" => "required"
        ]);

        try {
            DB::beginTransaction();
            $update = User::find($request->id);
            $update->name = $request->name;
            $update->email = $request->email;
            $update->phone = $request->phone;
            if ($request->password) {
                $update->password = Hash::make($request->password);
            }
            $update->role_id = $request->role;
            $update->save();
            if ($update->id) {
                $role = Role::findById($update->role_id);
                $update->syncRoles($role);
                DB::commit();
                return redirect()->route('system.user.list')->with("success", "User updated successfully");
            }
            return redirect()->back()->with("error", "Failed to update user");
        } catch (\Throwable $th) {
            DB::rollBack();
            Log::info($th);
        }
    }
}
