<?php

namespace App\Models;

use App\Traits\CreateUpdateDelete;
use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Adjustment extends Model
{
    use HasFactory;
    use SoftDeletes;
    use CreateUpdateDelete;

    protected function adjustmentTypeName(): Attribute
    {
        return Attribute::make(
            get: fn () => match ($this->adjustment_type) {
                1 => 'Minus(-)',
                2 => 'Plus(+)',
                default => 'Unknown',
            }
        );
    }

    // Computed property for adjustment for name
    protected function adjustmentForName(): Attribute
    {
        return Attribute::make(
            get: fn () => match ($this->adjustment_for) {
                1 => 'Commission',
                2 => 'Bonus',
                default => 'Unknown Purpose',
            }
        );
    }

    public function period()
    {
        return $this->belongsTo(Period::class, 'period_id', 'id');
    }

    public function agent()
    {
        return $this->belongsTo(Employee::class, 'login_id', 'login_id');
    }

    public function createdBy()
    {
        return $this->belongsTo(User::class, 'created_by', 'id');
    }

    public function updatedBy()
    {
        return $this->belongsTo(User::class, 'updated_by', 'id');
    }
}
