<?php

namespace App\Models;

use App\Traits\CreateUpdateDelete;
use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Employee extends Model
{
    use HasFactory;
    use SoftDeletes;
    use CreateUpdateDelete;

    protected $guarded = [];

    protected function importData(): Attribute
    {
        return Attribute::make(
            get: fn ($value) => json_decode($value),
            set: fn ($value) => json_encode($value),
        );
    }

    protected function socialChannelName(): Attribute
    {
        return Attribute::make(
            get: fn () => match ($this->social_channel) {
                1 => 'Whatsapp',
                2 => 'Telegram',
                3 => 'Skype',
                default => '',
            }
        );
    }

    // Computed property for adjustment for name
    protected function usdtNetworkName(): Attribute
    {
        return Attribute::make(
            get: fn () => match ($this->usdt_network) {
                1 => 'TRC20',
                2 => 'ERC20',
                default => '',
            }
        );
    }

    public function createdBy()
    {
        return $this->belongsTo(User::class, 'created_by', 'id');
    }

    public function updatedBy()
    {
        return $this->belongsTo(User::class, 'updated_by', 'id');
    }

    public function availCommissions() {
        return $this->hasMany(CommissionEmployee::class,'employee_id','id');
    }

    public function deposits() {
        return $this->hasMany(DepositEmployee::class,'employee_id','id');
    }

    public function affiliate() {
        return $this->belongsTo(Affiliate::class,'affiliate_id','id');
    }

    public function adjustments() {
        return $this->hasMany(Adjustment::class,'login_id','login_id');
    }

    public function additionAdjustments() {
        return $this->hasMany(Adjustment::class,'login_id','login_id')
            ->where('adjustment_type', 2)
            ->where('paid_status', 2);
    }

    public function deductionAdjustments() {
        return $this->hasMany(Adjustment::class,'login_id','login_id')
            ->where('adjustment_type', 1)
            ->where('paid_status', 2);
    }
}
