<?php

namespace App\Traits;

use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;

trait CreateUpdateDelete
{
    public static function bootCreateUpdateDelete()
    {
        // updating created_by and updated_by when model is created
        static::creating(function ($model) {
            if (!$model->isDirty('created_at')) {
                $model->created_at = Carbon::now();
            }
            if (!$model->isDirty('created_by')) {
                $model->created_by = Auth::id();
            }
        });

        // updating updated_by when model is updated
        static::updating(function ($model) {
            if (!$model->isDirty('updated_at')) {
                $model->updated_at = Carbon::now();
            }
            if (!$model->isDirty('updated_by')) {
                $model->updated_by = Auth::id();
            }
        });

        // deleting updated_by when model is updated
        static::deleting(function ($model) {
            if (!$model->isDirty('deleted_by')) {
                $model->deleted_by = Auth::id();
                $model->save();
            }
        });
    }
}
