<?php

namespace Database\Seeders;

use App\Models\User;
use Illuminate\Database\Seeder;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;
use Spatie\Permission\PermissionRegistrar;

class RoleAndPermissionSeeder extends Seeder
{
    /**
     * Run the database seeds.
     */
    public function run(): void
    {
        //Delete all permissions and set auto increment 1 
        DB::table('permissions')->delete();
        DB::statement("ALTER TABLE `permissions` AUTO_INCREMENT = 1");

        // Reset cached roles and permissions
        app()[PermissionRegistrar::class]->forgetCachedPermissions();

        // Create permissions

        //dashboard permission
        Permission::create(['name' => 'create dashboard']);
        Permission::create(['name' => 'view dashboard']);
        Permission::create(['name' => 'update dashboard']);
        Permission::create(['name' => 'delete dashboard']);

        //user management permission
        Permission::create(['name' => 'create user']);
        Permission::create(['name' => 'view user']);
        Permission::create(['name' => 'update user']);
        Permission::create(['name' => 'delete user']);

        //role management permission
        Permission::create(['name' => 'create role']);
        Permission::create(['name' => 'view role']);
        Permission::create(['name' => 'update role']);
        Permission::create(['name' => 'delete role']);

        $role = Role::where('name', 'Super Admin')->first();
        if (!$role) {
            $role = Role::create(['name' => 'Super Admin']);
        }

        $role->givePermissionTo(Permission::all());

        //create super admin and assign role
        $admin = User::where('id', 1)->first();
        if (!$admin) {
            $admin = new User();
            $admin->name = "Super Admin";
            $admin->email = "superadmin@gmail.com";
            $admin->password = Hash::make(12345678);
            $admin->role_id = $role->id;
            $admin->save();
            $admin->assignRole($role);
        } else {
            $admin->role_id = $role->id;
            $admin->save();
            $admin->assignRole($role);
        }
    }
}
