@extends('admin.layout.layout')
@section('page-title', 'Adjustment list')
@section('main-content')
    <div class="page-content">
        <!--breadcrumb-->
        <div class="page-breadcrumb d-none d-sm-flex align-items-center mb-3">
            <div class="breadcrumb-title pe-3">Period</div>
            <div class="ps-3">
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb mb-0 p-0">
                        <li class="breadcrumb-item"><a href="javascript:;"><i class="bx bx-home-alt"></i></a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">Commission</li>
                        <li class="breadcrumb-item active" aria-current="page">Adjustment</li>
                        <li class="breadcrumb-item active" aria-current="page">List</li>
                    </ol>
                </nav>
            </div>
        </div>
        <!--end breadcrumb-->

        <div class="card">
            <div class="card-body">
                <form action="" method="get">
                    <div class="d-lg-flex align-items-center mb-4 gap-3">
                        <div class="position-relative">
                            <input type="text" name="search" value="{{ request()->get('search') }}"
                                   class="form-control ps-5 radius-30" placeholder="Search here"> <span
                                class="position-absolute top-50 product-show translate-middle-y"><i
                                    class="bx bx-search"></i></span>
                        </div>
                        <div>
                            <button class="btn btn-primary radius-30" type="submit">Search</button>
                        </div>
                        @can('create role')
                            <div class="ms-auto"><a href="{{ route('commission.adjustment.create') }}"
                                                    class="btn btn-primary radius-30 mt-2 mt-lg-0"><i
                                        class="bx bxs-plus-square"></i>Add Adjustment</a></div>
                        @endcan
                    </div>
                </form>
                <div class="card card-body">
                    <table class="table table-striped table-bordered table-responsive mb-0">
                        <thead class="table-light">
                        <tr>
                            <th>SL#</th>
                            <th>AG login ID</th>
                            <th>Period</th>
                            <th>Adj. Type</th>
                            <th>Adj. For</th>
                            <th>Adjustment Amount</th>
                            <th>Paid Status</th>
                            <th>Remarks</th>
                            <th>Action By</th>
                            <th>Actions</th>
                        </tr>
                        </thead>
                        <tbody>
                        @forelse ($listData as $data)
                            <tr>
                                <td>
                                    <h6 class="mb-0 font-14">
                                        {{ $loop->iteration }}
                                    </h6>
                                </td>
                                <td>{{ $data->login_id ?? 'Unknown' }}</td>
                                <td>{{ $data->period->name ?? '' }}</td>
                                <td>{{$data->adjustment_type_name ?? ''}}</td>
                                <td>{{$data->adjustment_for_name ?? ''}}</td>
                                <td>
                                    @if($data?->adjustment_type == 1)
                                        <span class="text-dark">{{ $data->adjustment_amount ?? '' }}</span>
                                    @else
                                        <span class="text-danger">{{ $data->adjustment_amount ?? '' }}</span>
                                    @endif
                                </td>
                                <td>
                                    @if($data?->paid_status == 1)
                                        <span class="badge bg-success">Paid</span>
                                    @else
                                        <span class="badge bg-warning text-dark">Unpaid</span>
                                    @endif
                                </td>
                                <td style="max-width:10%;">{{ $data->remarks ?? '' }}</td>
                                <td>
                                    @if ($data?->updatedAt)
                                        <p class="mb-0">{{ $data?->updatedBy?->name }}</p>
                                        <small>{{ date('Y-m-d h:i:s a', strtotime($data->updated_at)) }}</small>
                                    @else
                                        <p class="mb-0">{{ $data?->createdBy?->name }}</p>
                                        <small>
                                            {{ date('Y-m-d h:i:s a', strtotime($data->created_at)) }}
                                        </small>
                                    @endif
                                </td>
                                <td>
                                    <div class="d-flex order-actions">
                                        @if($data?->paid_status != 1)
                                            @can('update role')
                                                <a href="{{ route('commission.adjustment.edit', $data->id) }}" class=""><i
                                                        class='bx bxs-edit'></i></a>
                                            @endcan
                                        @endif
                                    </div>
                                </td>
                            </tr>
                        @empty
                            <tr>
                                <td colspan="15">
                                    <h4 class="text-secondary text-center">No data found</h4>
                                </td>
                            </tr>
                        @endforelse

                        </tbody>
                    </table>
                </div>
                <div class="row">
                    <div class="col-12  mt-2">
                        {{ $listData->appends($_GET)->links() }}
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection
