@extends('admin.layout.report-layout')
@section('page-title', 'Adjustment')
@section('main-content')
    <div class="page-content">
        <!--breadcrumb-->
        <div class="page-breadcrumb d-none d-sm-flex align-items-center mb-3">
            <div class="breadcrumb-title pe-3">Adjustment</div>
            <div class="ps-3">
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb mb-0 p-0">
                        <li class="breadcrumb-item"><a href="javascript:;"><i class="bx bx-home-alt"></i></a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">Report</li>
                    </ol>
                </nav>
            </div>
        </div>
        <!--end breadcrumb-->

        <div class="card">
            <div class="card-body">
                <form action="" method="get">
                    <div class="d-lg-flex align-items-center mb-4 gap-3">
                        <div class="card-body">
                            <form action="" method="get">
                                <div class="mb-4">
                                    <div class="row mb-4">
                                        <div class="col-md-4">
                                            <label for="start_date" class="form-label">Start Date</label>
                                            <input type="hidden" value="{{request()->get('agent_id')}}"
                                                   name="agent_id"/>
                                            <input type="hidden" value="{{request()->get('payment_status')}}"
                                                   name="payment_status"/>
                                            <input type="date" value="{{request()->get('start_date')}}"
                                                   name="start_date" onchange="startDateChange(this.value)"
                                                   id="start_date" class="form-control datepicker" required/>
                                            @error('start_date')
                                            <div class="text-danger">{{ $message }}</div>
                                            @enderror
                                        </div>
                                        <div class="col-md-4">
                                            <label for="end_date" class="form-label">End Date</label>
                                            <input type="date" onchange="endDateChange(this.value)" value="{{request()->get('end_date')}}" name="end_date"
                                                   id="end_date" class="form-control datepicker" required/>
                                            @error('end_date')
                                            <div class="text-danger">{{ $message }}</div>
                                            @enderror
                                        </div>
                                        <div class="col-md-4">
                                            <label for="adjustment_type" class="form-label">Adjustment Type</label>
                                            <select class="form-select" name="adjustment_type" id="adjustment_type"
                                                    data-placeholder="Choose anything">
                                                <option @if(request()->get('adjustment_type') == 'all') selected
                                                        @endif value="all">All
                                                </option>
                                                <option @if(request()->get('adjustment_type') == 2) selected
                                                        @endif value="2">Addition
                                                </option>
                                                <option @if(request()->get('adjustment_type') == 1) selected
                                                        @endif value="1">Deduction
                                                </option>
                                            </select>
                                            @error('adjustment_type')
                                            <div class="text-danger">{{ $message }}</div>
                                            @enderror
                                        </div>
                                    </div>
                                </div>

                                <div class="mb-4">
                                    <div class="row">
                                        <div class="col-md-4">
                                            <button type="submit" class="btn btn-primary"><i
                                                    class="lni lni-search-alt"></i> Search
                                            </button>
                                        </div>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </form>
                <div class="card card-body table-responsive">
                    <table class="table table-striped table-bordered mb-0">
                        <thead class="table-light">
                        <tr>
                            <th>SL#</th>
                            <th>Affiliate</th>
                            <th>Agent ID</th>
                            <th>Agent Name</th>
                            <th>Email</th>
                            <th>Phone</th>
                            <th>Period</th>
                            <th>Adjustment Type</th>
                            <th>Adjustment For</th>
                            <th>Adjustment Amount</th>
                        </tr>
                        </thead>
                        <tbody>
                        @forelse($data as $adj)
                            <tr>
                                <td>{{ $loop->iteration}}</td>
                                <td>{{$adj?->agent?->affiliate?->name }}</td>
                                <td>{{$adj->login_id }}</td>
                                <td>{{$adj?->agent?->emp_name }}</td>
                                <td>{{$adj?->agent?->email }}</td>
                                <td>{{$adj?->agent?->phone }}</td>
                                <td>{{ $adj?->period?->name}}</td>
                                <td>{{ $adj->adjustment_type_name }}</td>
                                <td>{{ $adj->adjustment_for_name }}</td>
                                <td>{{ $adj->adjustment_amount }}</td>
                            </tr>
                        @empty
                            <tr>
                                <td colspan="15" class="text-center">No adjustment found</td>
                            </tr>
                        @endforelse
                        </tbody>
                    </table>
                </div>
                <div class="row">
                    <div class="col-12">

                    </div>
                </div>
            </div>
        </div>

    </div>
@endsection

@section('extra-script')
    <script>
        const startDateElement = document.querySelector('#start_date');
        const endDateElement = document.querySelector('#end_date');
        function endDateChange(value) {
            const startDate = new Date(startDateElement.value);
            const endDate = new Date(value);
            if (startDate > endDate) {
                alert('End date cannot be smaller than start date.');
                endDateElement.value = '';
                return false;
            }

            let diffInDays = (endDate - startDate) / (1000 * 60 * 60 * 24);

            if (diffInDays > 90) {
                alert('Date range cannot be greater than 90 days.');
                endDateElement.value = '';
                return false;
            }
        }

        function startDateChange(value) {
            const startDate = new Date(value);
            const endDate = new Date(endDateElement.value);
            if (startDate > endDate) {
                alert('Start date cannot be greater than end date.');
                startDateElement.value = '';
                return false;
            }

            let diffInDays = (endDate - startDate) / (1000 * 60 * 60 * 24);

            if (diffInDays > 90) {
                alert('Date range cannot be greater than 90 days.');
                startDateElement.value = '';
                return false;
            }
        }
    </script>
@endsection
