<?php

use App\Http\Controllers\Auth\AuthController;
use App\Http\Controllers\Commission\Agent\AgentController;
use App\Http\Controllers\Commission\CommissionController;
use App\Http\Controllers\Commission\CommissionImportController;
use App\Http\Controllers\Commission\PeriodController;
use App\Http\Controllers\Commission\AdjustmentController;
use App\Http\Controllers\Dashboard\DashboardController;
use App\Http\Controllers\Mail\MailController;
use App\Http\Controllers\Report\ReportController;
use App\Http\Controllers\System\Role\RoleController;
use App\Http\Controllers\System\User\UserController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::get('/', function () {
    return redirect()->route("auth.login");
});


Route::group(["prefix" => "auth"], function () {
    Route::get("login", [AuthController::class, "login"])->name("auth.login");
    Route::post("submit-login", [AuthController::class, "submitLogin"])->name("auth.submit_login");
    Route::get("logout", [AuthController::class, "logout"])->name("auth.logout")->middleware("auth");
});

Route::group(["prefix" => "admin", "middleware" => "auth"], function () {
    Route::get("dashboard", [DashboardController::class, "dashboardInfo"])->name("admin.dashboard");

    /*--------------- system route ---------------*/
    Route::group(["prefix" => "system"], function () {
        /*--------------- role management ---------------*/
        Route::group(["prefix" => "role"], function () {
            Route::get("role-list", [RoleController::class, "roleList"])->name("system.role.list")->middleware(['can:view role']);
            Route::get("create-role", [RoleController::class, "createRole"])->name("system.role.create")->middleware(['can:create role']);
            Route::post("submit-create-role", [RoleController::class, "submitCreateRole"])->name("system.role.submit_create")->middleware(['can:create role']);
            Route::get("view-role/{id}", [RoleController::class, "viewRole"])->name("system.role.view")->middleware(['can:update role']);
            Route::post("update-role", [RoleController::class, "updateRole"])->name("system.role.update")->middleware(['can:update role']);
        });
        /*--------------- user management ---------------*/
        Route::group(["prefix" => "user"], function () {
            Route::get("user-list", [UserController::class, "userList"])->name("system.user.list")->middleware(['can:view user']);
            Route::get("create-user", [UserController::class, "createUser"])->name("system.user.create")->middleware(['can:create user']);
            Route::post("submit-create-user", [UserController::class, "submitCreateUser"])->name("system.user.submit_create")->middleware(['can:create user']);
            Route::get("view-user/{id}", [UserController::class, "viewUser"])->name("system.user.view")->middleware(['can:update user']);
            Route::post("update-user", [UserController::class, "updateUser"])->name("system.user.update")->middleware(['can:update user']);
        });
    });

    /*--------------- commission route ---------------*/
    Route::group(["prefix" => "commission"], function () {

        Route::group(["prefix" => "period"], function () {
            Route::get("period-list", [PeriodController::class, "index"])->name("commission.period.list");//->middleware(['can:view period']);
            Route::get("create-period", [PeriodController::class, "create"])->name("commission.period.create");//->middleware(['can:create period']);
            Route::post("submit-create-period", [PeriodController::class, "store"])->name("commission.period.submit_create");//->middleware(['can:create period']);
            Route::get("view-period/{id}", [PeriodController::class, "view"])->name("commission.period.view");//->middleware(['can:update period']);
            Route::post("update-period", [PeriodController::class, "update"])->name("commission.period.update");//->middleware(['can:update period']);
        });

        Route::group(["prefix" => "import"], function () {
            //commission
            Route::get("import-user-list", [CommissionImportController::class, "pendingIndex"])->name("import.user.list");
            Route::get("import-list", [CommissionImportController::class, "index"])->name("commission.import.list");//->middleware(['can:view import']);
            Route::get("create-import", [CommissionImportController::class, "create"])->name("commission.import.create");//->middleware(['can:create import']);
            Route::post("submit-create-import", [CommissionImportController::class, "store"])->name("commission.import.submit_create");//->middleware(['can:create import']);
            Route::get("view-import/{id}", [CommissionImportController::class, "view"])->name("commission.import.view");//->middleware(['can:update import']);
            Route::post("update-import", [CommissionImportController::class, "update"])->name("commission.import.update");//->middleware(['can:update import']);

            //deposit
            Route::get("deposit-import-list", [CommissionImportController::class, "depositIndex"])->name("deposit.import.list");//->middleware(['can:view import']);
            Route::get("create-deposit-import", [CommissionImportController::class, "createDeposit"])->name("deposit.import.create");//->middleware(['can:create import']);
            Route::post("submit-deposit-import", [CommissionImportController::class, "storeDeposit"])->name("deposit.import.submit_create");//->middleware(['can:creat
            Route::get("view-deposit-import/{id}", [CommissionImportController::class, "viewDeposit"])->name("deposit.import.view");//->middleware(['can:update import']);
        });

        Route::group(["prefix" => "payout-user"], function () {
            Route::get("pending-list", [CommissionController::class, "pendingIndex"])->name("commission.pending.list");//->middleware(['can:view import']);
            Route::get("unpaid-view/{id}", [CommissionController::class, "unpaidView"])->name("commission.available_user.unpaid_view");//->middleware(['can:update import']);
            Route::get("paid-list", [CommissionController::class, "paidIndex"])->name("commission.paid.list");//->middleware(['can:view import']);
            Route::get("paid-view/{id}", [CommissionController::class, "paidView"])->name("commission.paid.view");//->middleware(['can:update import']);
            Route::get("download-unpaid-invoice/{id}", [CommissionController::class, "downloadUnpaidInvoice"])->name("commission.available_user.invoice_download");//->middleware(['can:update import']);
            Route::get("download-paid-invoice/{id}", [CommissionController::class, "downloadPaidInvoice"])->name("commission.paid.invoice_download");//->middleware(['can:update import']);
            Route::get("update/{id}", [CommissionController::class, "updateStatus"])->name("commission.available_user.status_update");//->middleware(['can:update import']);

            Route::get("payment-request-list", [CommissionController::class, "paymentRequestIndex"])->name("commission.payment.request.list");
            Route::get("payment-request-download", [CommissionController::class, "paymentRequestDownload"])->name("commission.payment.request.download");
            Route::get("release-payment-request", [CommissionController::class, "releasePayment"])->name("commission.payment.request.release");
            Route::get("payment-request-view/{id}", [CommissionController::class, "paymentRequestView"])->name("commission.payment.request.view");
        });

        Route::group(["prefix" => "agent"], function () {
            Route::get("agent-list", [AgentController::class, "index"])->name("commission.agent.list")->middleware(['can:view user']);
            Route::get("create-agent", [AgentController::class, "create"])->name("commission.agent.create")->middleware(['can:create user']);
            Route::post("submit-create-agent", [AgentController::class, "store"])->name("commission.agent.submit_create")->middleware(['can:create user']);
            Route::get("import-agent", [AgentController::class, "createImport"])->name("commission.agent.import")->middleware(['can:create user']);
            Route::post("submit-import-agent", [AgentController::class, "importAgent"])->name("commission.agent.submit_import")->middleware(['can:create user']);
            Route::get("edit-agent/{id}", [AgentController::class, "edit"])->name("commission.agent.edit")->middleware(['can:update user']);
            Route::post("update-agent", [AgentController::class, "update"])->name("commission.agent.update")->middleware(['can:update user']);
        });

        Route::group(["prefix" => "adjustment"], function () {
            Route::get("adjustment-list", [AdjustmentController::class, "index"])->name("commission.adjustment.list")->middleware(['can:view user']);
            Route::get("adjustment-create", [AdjustmentController::class, "create"])->name("commission.adjustment.create")->middleware(['can:view user']);
            Route::post("adjustment-store", [AdjustmentController::class, "store"])->name("commission.adjustment.store")->middleware(['can:view user']);
            Route::get("adjustment-edit/{id}", [AdjustmentController::class, "edit"])->name("commission.adjustment.edit")->middleware(['can:view user']);
            Route::post("adjustment-update", [AdjustmentController::class, "update"])->name("commission.adjustment.update")->middleware(['can:view user']);
        });
    });

    /*.................... report ....................*/
    Route::group(["prefix" => "report"], function () {
        Route::get("commission-report", [ReportController::class, "commissionReport"])->name("commission.report.list");
        Route::get("commission-report-export", [ReportController::class, "commissionReportExport"])->name("commission.report.export");
        Route::group(["prefix" => "report-tab"], function () {
            Route::get("overview-report-tab", [ReportController::class, "overviewReportTab"])->name("overview.report.tab");
            Route::get("deposit-report-tab", [ReportController::class, "depositReportTab"])->name("deposit.report.tab");
            Route::get("commission-report-tab", [ReportController::class, "commissionReportTab"])->name("commission.report.tab");
            Route::get("commission-report-tab-export", [ReportController::class, "commissionReportTabExport"])->name("commission.report.tab.export");
            Route::get("adjustment-report-tab", [ReportController::class, "adjustmentReportTab"])->name("adjustment.report.tab");
        });
    });

    /*.................... mail ....................*/
    Route::group(["prefix" => "mail"],function() {
        Route::get("send-pending-commission-mail",[MailController::class,'sendPendingPayoutMail'])->name('mail.pending.commission');
    });

});
